# Parametric section

This module calculates the hydraulic quantities associated to:

- a section with a defined geometrical shape ([See section types managed by Cassiopée](types_sections.md))
- a draft \(y\) in m
- a flow \(Q\) in m<sup>3</sup>/s
- a bottom slope \(I_f\) in m/m
- a roughness expressed with the Strickler's coefficient \(K\) in m<sup>1/3</sup>/s

The calculated hydraulic quantities are:

- Width at mirror (m)
- Wet perimeter (m)
- Hydraulic surface (m<sup>2</sup>)
- Hydraulic radius (m)
- Average speed (m/s)
- Specific head (m)
- Head loss (m)
- Linear variation of specific energy (m/m)
- Normal depth (m)
- Froude number
- Critical depth (m)
- Critical head (m)
- Corresponding depth (m)
- Impulsion (kg⋅m⋅s<sup>-1</sup>)
- Conjugate depth
- Tractive force (Pa)

## Width at mirror, wet perimeter and surface

[See the dedicated page for the parameters specific to each type of section](types_sections.md)

### Rectangular section

- Width at mirror : \(B=L\)
- Surface : \(S=L.y\)
- Perimeter : \(P=L+2y\)

### Trapezoidal section

- Width at mirror : \(B=L+2..m.y\)
- Surface : \(S=(L+m.y)y\)
- Perimeter : \(P=L+2y\sqrt{1+m^2}\)

### Circular section

- Width at mirror : \(B=D\sin\theta\)
- Surface : \(S=\frac{D^2}{4} \left(\theta - \sin\theta.\cos\theta \right)\)
- Perimeter : \(P=D.\theta\)

### Parabolic section

- Width at mirror : \(B=\frac{B_b}{y_b^k}y^k\)
- Surface : \(S=\frac{B_b}{y_b^k}\frac{y^{k+1}}{k+1}\)
- Perimeter : \(P=2\sum _{i=1}^{n}\sqrt{\frac{1}{n^2}+\frac{1}{4}\left( B\left(\frac{i.y}{n}\right)-B\left(\frac{(i-1).y}{n}\right) \right)^2}\) for \(n\) large enough

## Hydraulic radius (m)

$$R = S / P$$

## Average speed (m/s)

$$U = Q /S$$

## Specific head (m)

$$H(y) = y + \frac{U^2}{2g}$$

## Head loss (m/m)

Cassiopée uses Manning Strickler formula:

$$J=\frac{U^2}{K^{2}R^{4/3}}=\frac{Q^2}{S^2K^{2}R^{4/3}}$$

## Linear variation of specific energy (m/m)

$$\Delta E_s = I_f - J$$

## Normal depth (m)

[See the uniform flow calculation.](regime_uniforme.md)

## Froude number

The Froude number expresses the ratio between the mean fluid velocity and the surface wave velocity. \(c\).

$$ c = \sqrt{\frac{gS}{B}}$$

$$ Fr = \frac{U}{c} = \sqrt{\frac{Q^2B}{gS^3}}$$

## Critical head (m)

The critical height is reached when the average velocity of the fluid is equal to the velocity of the waves on the water surface.

The critical height is therefore reached when the Froude number \(Fr=1\).

For any section, the critical height is calculated as follows \(y_c\) by solving \(f(y_c)=Fr^2-1=0\)

We use Newton's method by posing \(y_{k+1} = y_k - \frac{f(y_k)}{f'(y_k)}\) with :
- \(f(y_k) = \frac{Q^2 B}{g S^3} - 1\)
- \(f'(y_k) = \frac{Q^2}{g} \frac{B'.S - 3 B S'}{S^4}\)

## Critical head (m)

This is the head calculated for a draft equal to the critical depth. \(H_c = H(y_c)\).

## Corresponing depth (m)

For a fluvial (respectively torrential draft) \(y\), corresponding depth is the torrential (respectively fluvial) draft for the which \(H(y) = H(y_{cor})\).

## Hydraulic impulsion (kg⋅m⋅s<sup>-1</sup>)

The impulsion \(I\) is the sum of the amount of movement and the resultant of the pressure force in a section:

$$I=\rho Q U + \rho g S y_g$$

With :

- \(\rho\) : the density of water (kg/m<sup>3</sup>)
- \(y_g\) : the distance from the centre of gravity of the section to the free surface (m)

The distance from the centre of gravity of the section to the free surface \(y_g\) can be found from the formula :

$$S.y_g = \int_{0}^{y} (y-z)B(z)dz$$

With \(y\) the depth and \(B(z)\) the width at mirror for a draft \(z\)

Formulas of \(S.y_g\) for the different section shapes are :

- rectangular section: \(S.y_g = \frac{L.y^2}{2}\)
- trapezoidal section: \(S.y_g = \left (\frac{L}{2} + \frac{m.y}{3} \right )y^2\)
- circular section: \(S.y_g = \frac{D^3}{8}\left (\sin\theta - \frac{\sin^3\theta}{3} - \theta \cos\theta \right )\)
- parabolic section: \(S.y_g=\frac{B_b.y^{k+2}}{y_b^k(k+1)(k+2)}\)

## Tractive force (Pa)

$$ \tau_0 = \rho g R J $$
