# Hydraulic variables

<div style="position: relative"><a id="largeur-au-miroir-b" style="position: absolute; top: -60px;"></a></div>
## Width at mirror B

#### Rectangular section
\(B=L\)

\(B'=\dfrac{dB}{dy}=0\)

#### Circular section
\(B=D\sin\theta\)

\(B'=\dfrac{dB}{dy}=D.\theta'\cos\theta\)

#### Trapezoidal section
\(B=L+2..m.y\)

\(B'=\dfrac{dB}{dy}=2.L.m\)

#### Parabolic section
\(B=\dfrac{B_b}{y_b^k}y^k\)

\(B'=\dfrac{dB}{dy}=\dfrac{B_b.k}{y_b^k}y^{k-1}\)

<div style="position: relative"><a id="perimetre-mouille-p" style="position: absolute; top: -60px;"></a></div>
## Wet perimeter P

#### Rectangular section
\(P=L+2y\)

\(P'=\dfrac{dP}{dy}=2\)

#### Circular section
\(P=D.\theta\)

\(P'=\dfrac{dP}{dy}=D.\theta'\)

#### Trapezoidal section
\(P=L+2y\sqrt{1+m^2}\)

\(P'=\dfrac{dP}{dy}=2\sqrt{1+m^2}\)

#### Parabolic section
\(P=2\sum _{i=1}^{n}\sqrt{\dfrac{1}{n^2}+\dfrac{1}{4}\left( B\left(\dfrac{i.y}{n}\right)-B\left(\dfrac{(i-1).y}{n}\right) \right)^2}\) for n large enough

\(P'=\dfrac{dP}{dy}=2\sqrt{1+\left(\dfrac{B'}{2} \right )^2}\)

<div style="position: relative"><a id="surface-mouillee-s" style="position: absolute; top: -60px;"></a></div>
## Wet surface S

#### Rectangular section
\(S=L.y\)

\(S'=\dfrac{dS}{dy}=B\)

#### Circular section
\(S=\dfrac{D^2}{4} \left(\theta - \sin\theta.\cos\theta \right)\)

\(S'=\dfrac{dS}{dy}=B\)

#### Trapezoidal section
\(S=(L+m.y)y\)

\(S'=\dfrac{dS}{dy}=B\)

#### Parabolic section
\(S=\dfrac{B_b}{y_b^k}\dfrac{y^{k+1}}{k+1}\)

\(S'=\dfrac{dS}{dy}=B\)

<div style="position: relative"><a id="rayon-hydraulique-r" style="position: absolute; top: -60px;"></a></div>
## Rayon hydraulique R

\(\dfrac{S}{P}\)

<div style="position: relative"><a id="froude-fr" style="position: absolute; top: -60px;"></a></div>
## Froude Fr

\(Fr=\dfrac{U}{c}=\sqrt{\dfrac{Q^2 B}{g S^3}}\)

<div style="position: relative"><a id="vitesse-moyenne-v" style="position: absolute; top: -60px;"></a></div>
## Average speed V

\(V=\dfrac{Q}{S}\)

<div style="position: relative"><a id="tirant-deau-normal-yn" style="position: absolute; top: -60px;"></a></div>
## Normal depth Yn

The normal depth is reached when the water line is parallel to the bottom, the load is then itself parallel to the water line and therefore the head loss is equal to the slope of the bottom: \(If=J\)

With:

 * \(I_f\): the slope of the bottom (en m/m)
 * \(J\): the head loss (en m/m )

To calculate the normal depth \(Y_n\), one may solve

\(f(Y_n)=Q-KR^{2/3}S\sqrt{I_f}=0\)

using Newton's method:

\(h_{k+1} = h_k - \dfrac{f(h_k)}{f'(h_k)}\)

with:

 * \(f(h_k) = Q-KR^{2/3}S\sqrt{I_f}\)
 * \(f'(h_k) = -K \sqrt{I_f}(\dfrac{2}{3}R'R^{-1/3}S+R^{2/3}S')\)


<div style="position: relative"><a id="tirant-deau-critique-yc" style="position: absolute; top: -60px;"></a></div>
## Critical depth Yc

Critical depth is reached when Froude number \(Fr=1\).

\(f(Y_c)=Fr^2-1=0\)

We use Newton's method, posing

\(h_{k+1} = h_k - \dfrac{f(h_k)}{f'(h_k)}\)

with:

 * \(f(h_k) = \dfrac{Q^2 B}{g S^3} - 1\)
 * \(f'(h_k) = \dfrac{Q^2}{g} \dfrac{B'.S - 3 B S'}{S^4}\)

<div style="position: relative"><a id="tirant-deau-correspondant-ycor" style="position: absolute; top: -60px;"></a></div>
## Corresponding depth Ycor

<div style="position: relative"><a id="tirant-deau-conjugue-ycon" style="position: absolute; top: -60px;"></a></div>
## Conjugate depth Ycon

<div style="position: relative"><a id="charge-specifique-hs" style="position: absolute; top: -60px;"></a></div>
## Specific head Hs

\(H_s = \dfrac{V^{2}}{2g}\)

<div style="position: relative"><div style="position: relative"><a id="charge-critique-hsc" style="position: absolute; top: -100px;" style="position: absolute; top: -60px;"></a></div></div>
## Critical head Hsc

\(H_{sc} = Y_c + \dfrac{V(Y_c)^{2}}{2g}\)

<div style="position: relative"><a id="perte-de-charge-j" style="position: absolute; top: -60px;"></a></div>
## Head loss J

Head loss \(J\) is calculating using Manning-Strickler formula:

\(J=\dfrac{U^2}{K^{2}R^{4/3}}=\dfrac{Q^2}{S^2K^{2}R^{4/3}}\)


With \(K\) ths Strickler coefficient (in \(m^{1/3}/s\))

<div style="position: relative"><a id="variation-lineaire-de-lenergie-specifique-i-j" style="position: absolute; top: -60px;"></a></div>
## Linear variation of specific energy I-J

<div style="position: relative"><a id="impulsion-imp" style="position: absolute; top: -60px;"></a></div>
## Impulsion Imp

It is the sum of the amount of movement and the resultant of the pressure force in a section:

\(I=\rho Q U + \rho g S \overline{h}\)

With:

 * \(I\): the impulsion (kg.m.s-2)
 * \(\rho\): the density of water (kg/m3)
 * \(Q\): the flow (m3.s-1)
 * \(V\): the average fluid velocity in the section (m.s-1)
 * \(g\): the gravity constant (m.s-2)
 * \(S\): the wet surface (m2)
 * \(\overline{h}\): the distance from the centre of gravity of the section to the free surface (m)

The distance from the centre of gravity of the section to the free surface \(\overline{h}\) can be traced back using the formula:

\(S.\overline{h} = \int_{0}^{y} (y-z)B(z)dz\)

With \(y\) the depth and \(B(z)\) the width at mirror, for a draft \(z\)

#### Rectangular section

\(S.h = \dfrac{L.y^2}{2}\)

#### Circular section

\(S.h = \dfrac{D^3}{8}\left (\sin\theta - \dfrac{\sin^3\theta}{3} - \theta \cos\theta \right )\)

#### Trapezoidal section

\(S.h = \left (\dfrac{L}{2} + \dfrac{m.y}{3} \right )y^2\)

#### Parabolic section

\(S.h=\dfrac{B_b.y^{k+2}}{y_b^k(k+1)(k+2)}\)

<div style="position: relative"><a id="force-tractrice-tau0" style="position: absolute; top: -60px;"></a></div>
## Tractive force Tau0
